summaryrefslogtreecommitdiff
path: root/lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h
diff options
context:
space:
mode:
authorJonathan Gray <jsg@cvs.openbsd.org>2020-01-22 02:13:18 +0000
committerJonathan Gray <jsg@cvs.openbsd.org>2020-01-22 02:13:18 +0000
commitfdcc03929065b5bf5dd93553db219ea3e05c8c34 (patch)
treeca90dc8d9e89febdcd4160956c1b8ec098a4efc9 /lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h
parent3c9de4a7e13712b5696750bbd59a18c848742022 (diff)
Import Mesa 19.2.8
Diffstat (limited to 'lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h')
-rw-r--r--lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h b/lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h
index a604167f0..6e5c736fd 100644
--- a/lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h
+++ b/lib/mesa/src/gallium/auxiliary/util/u_debug_flush.h
@@ -47,12 +47,12 @@ struct debug_flush_ctx;
/**
* Create a buffer (AKA allocation) representation.
*
* @param support_unsync Whether unsynchronous maps are truly supported.
* @param bt_depth Depth of backtrace to be captured for this buffer
* representation.
*/
struct debug_flush_buf *
-debug_flush_buf_create(boolean supports_unsync, unsigned bt_depth);
+debug_flush_buf_create(boolean supports_persistent, unsigned bt_depth);
/**
* Reference a buffer representation.
@@ -47,12 +47,12 @@ struct debug_flush_ctx;
* Create a buffer (AKA allocation) representation.
*
- * @param support_unsync Whether unsynchronous maps are truly supported.
+ * @param supports_persistent Whether persistent maps are truly supported.
* @param bt_depth Depth of backtrace to be captured for this buffer
* representation.